%{!?python_sitelib:%global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch:%global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%define ENABLE_TESTS -DENABLE_TESTS:BOOL=ON

Name:           avogadro
Version:        1.1.1
Release:        10%{?dist}
Summary:        An advanced molecular editor for chemical purposes

License:        GPLv2
URL:            http://avogadro.openmolecules.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2

## upstreamable patches
# Fix qmake mkspecs installation directory
Patch0:         avogadro-1.1.1-mkspecs-dir.patch
# Remove -Wl,-s from the compiler flags, fixes -debuginfo (#700080)
Patch1:         avogadro-1.1.1-no-strip.patch
# avogadro.pc missing eigen dependency
Patch2:         avogadro-1.1.1-pkgconfig_eigen.patch

## upstream fixes
# fix FTBFS on arm
Patch3:         0029-Fix-compilation-on-ARM-where-qreal-can-be-defined-as.patch

## upstreamable
# fix build with cmake-3.2+
# https://sourceforge.net/p/avogadro/bugs/746/
Patch10:        avogadro-cmake-3.2.patch

# fix Eigen3 support, from OpenMandriva (Bernhard Rosenkränzer, Crispin Boylan)
# disables Eigen2 support, so probably not upstreamable as is
Patch11:        avogadro-1.1.1-eigen3.patch

BuildRequires:  boost-devel >= 1.35
BuildRequires:  cmake >= 2.6.0
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-utils
BuildRequires:  numpy
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(glew) >= 1.5.0
BuildRequires:  pkgconfig(openbabel-2.0) >= 2.2.2
BuildRequires:  pkgconfig(QtGui) pkgconfig(QtNetwork) pkgconfig(QtOpenGL)
BuildRequires:  sip-devel
%if 0%{?ENABLE_TESTS:1}
BuildRequires: dbus-x11 xorg-x11-server-Xvfb
%endif

Requires: %{name}-libs%{?_isa} = %{version}-%{release}

%description
An advanced molecular editor designed for 
cross-platform use in computational chemistry,
molecular modeling, bioinformatics, materials science,
and related areas, which offers flexible rendering and
a powerful plugin architecture.


%package libs
Summary:        Shared libraries for Avogadro
%{?_sip_api:Requires: sip-api(%{_sip_api_major}) >= %{_sip_api}}
%description libs
This package contains the shared libraries for the
molecular editor Avogadro.

%package devel
Summary:        Development files for Avogadro
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
%description devel
This package contains files to develop applications using 
Avogadro libraries.


%prep
%setup -q
%patch0 -p1 -b .mkspecs-dir
%patch1 -p1 -b .no-strip
%patch2 -p1 -b .pkgconfig_eigen
%patch3 -p1 -b .qreal
%patch10 -p1 -b .cmake_x11
%patch11 -p1 -b .eigen3


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake} \
  %{?ENABLE_TESTS} \
  -DENABLE_GLSL:BOOL=ON \
  -DENABLE_PYTHON:BOOL=ON  \
  -DENABLE_RPATH:BOOL=OFF \
  -DENABLE_VERSIONED_PLUGIN_DIR:BOOL=OFF \
  ..
popd
make %{?_smp_mflags} -C %{_target_platform}


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

%find_lang libavogadro --with-qt --without-mo
%find_lang avogadro --with-qt --without-mo


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/avogadro.desktop
%if 0%{?ENABLE_TESTS:1}
xvfb-run -a dbus-launch --exit-with-session make test ARGS="--output-on-failure" -C %{_target_platform} ||:
%endif


%files -f avogadro.lang
%{_bindir}/avogadro
%{_bindir}/avopkg
%{_datadir}/avogadro/builder/
%{_datadir}/avogadro/crystals/
%{_datadir}/avogadro/fragments/
%{_datadir}/pixmaps/avogadro-icon.png
%{_datadir}/applications/avogadro.desktop
%{_mandir}/man1/avogadro.1*
%{_mandir}/man1/avopkg.1*

%files devel
%{_includedir}/avogadro/
%{_libdir}/libavogadro.so
%{_libdir}/libavogadro_OpenQube.so
%{_libdir}/pkgconfig/avogadro.pc
%{_libdir}/avogadro/*.cmake
%{_libdir}/avogadro/cmake/
%{_qt4_prefix}/mkspecs/features/avogadro.prf

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files libs -f libavogadro.lang
%doc AUTHORS ChangeLog COPYING
# package python bits elsewhere/separately? -- rex
%{python_sitearch}/Avogadro.so
%{_datadir}/libavogadro/
%dir %{_datadir}/avogadro/
%dir %{_datadir}/avogadro/i18n/
%{_libdir}/libavogadro.so.1*
%{_libdir}/libavogadro_OpenQube.so.0*
%dir %{_libdir}/avogadro/
%{_libdir}/avogadro/colors/
%{_libdir}/avogadro/extensions/
%{_libdir}/avogadro/engines/
%{_libdir}/avogadro/tools/


%changelog
* Sun Mar 29 2015 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.1.1-10
- apply OpenMandriva patch to fix Eigen3 support
- build against Eigen3: change BuildRequires, pkgconfig_eigen patch

* Wed Mar 25 2015 Rex Dieter <rdieter@fedoraproject.org> 1.1.1-9
- rebuild (gcc5)

* Wed Feb 25 2015 Rex Dieter <rdieter@fedoraproject.org> 1.1.1-8
- rebuild (gcc5)

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 1.1.1-7
- Rebuild for boost 1.57.0

* Mon Sep 22 2014 Rex Dieter <rdieter@fedoraproject.org> 1.1.1-6
- pull in upstream fix for qreal/arm issues

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 1.1.1-3
- Rebuild for boost 1.55.0

* Sun Mar 16 2014 Rex Dieter <rdieter@fedoraproject.org> 1.1.1-2
- rebuild(sip)

* Sat Jan 25 2014 Rex Dieter <rdieter@fedoraproject.org> 1.1.1-1
- avogadro-1.1.1
- ExcludeArch: arm

* Mon Nov 18 2013 Dave Airlie <airlied@redhat.com> - 1.0.3-21
- rebuilt for GLEW 1.10

* Wed Oct 16 2013 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-20
- rebuild (sip)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 1.0.3-18
- Rebuild for boost 1.54.0

* Mon Jun 17 2013 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-17
- rebuild (sip)

* Mon Feb 11 2013 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-16
- drop boost patch, qt/moc has workaround now

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.0.3-15
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.0.3-14.1
- Rebuild for Boost-1.53.0

* Thu Dec 13 2012 Adam Jackson <ajax@redhat.com> - 1.0.3-13.1
- Rebuild for glew 1.9.0

* Mon Oct 01 2012 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-12
- rebuild (sip)

* Thu Aug 09 2012 Rex Dieter <rdieter@fedoraproject.org> - 1.0.3-11
- rebuild (boost)

* Fri Jul 27 2012 Rex Dieter <rdieter@fedoraproject.org> - 1.0.3-10
- rebuild (glew)
- pkgconfig-style deps

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-8
- Rebuilt for c++ ABI breakage

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Dec 23 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-6
- rebuild (sip/PyQt4)

* Tue Nov 22 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1.0.3-5
- Rebuild for boost 1.48

* Thu Jul 21 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-4
- rebuild (boost)

* Mon Jun 20 2011 ajax@redhat.com - 1.0.3-3
- Rebuild for new glew soname

* Wed Apr 27 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.3-2
- remove -Wl,-s from the compiler flags, fixes -debuginfo (#700080)

* Tue Apr 26 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.3-1
- update to 1.0.3
- drop all patches (fixed upstream)
- fix qmake mkspecs installation directory (broken in 1.0.3)

* Fri Apr 08 2011 Jaroslav Reznik <jreznik@redhat.com> - 1.0.1-15
- rebuild for new boost (1.46.1)

* Tue Mar 22 2011 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-14
- fix forcefield extension with OpenBabel 2.3.0 (#680292, upstream patch)
- fix autooptimization tool with OpenBabel 2.3.0 (#680292, patch by lg)

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 07 2011 Thomas Spura <tomspur@fedoraproject.org> - 1.0.1-12
- rebuild for new boost

* Thu Nov 25 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-11
- rebuild for new openbabel (2.3.0)

* Tue Nov 23 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-10
- fix crash with current SIP and Python 2.7 (#642248)

* Wed Sep 29 2010 jkeating - 1.0.1-9
- Rebuilt for gcc bug 634757

* Tue Sep 14 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-8
- fix FTBFS with SIP 4.11 (Gentoo#335644)

* Thu Sep 09 2010 Rex Dieter <rdieter@fedoraproject.org> - 1.0.1-7
- rebuild(sip)

* Sun Aug 22 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-6
- -devel: Requires: glew-devel python-devel boost-devel

* Sun Aug 22 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-5
- use CMAKE_SKIP_RPATH because we end up with rpaths otherwise
- disable tests because they don't work in Koji anyway

* Sun Aug 22 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.1-4
- fix paths in AvogadroConfig.cmake
- fix packaging of translations

* Wed Aug 04 2010 Rahul Sundaram <sundaram@fedoraproject.org> - 1.0.1-3
- Rebuild for Boost soname bump

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon May 24 2010 Rex Dieter <rdieter@fedoraproject.org> - 1.0.1-1
- avogadro-1.0.1
- -devel: move cmake-related files here
- -devel: Req: qt4-devel
- %%files: track lib sonames
- %%check section

* Wed Feb 10 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 1.0.0-6
- reenable plugin builds and libs subpackage
- fix their build with sip 4.10

* Fri Jan 08 2010 Sebastian Dziallas <sebastian@when.com> - 1.0.0-5
- disable plugin builds and libs subpackage

* Thu Jan 07 2010 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-4
- rebuild (sip)

* Mon Nov 23 2009 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-3 
- rebuild (for qt-4.6.0-rc1, f13+)

* Mon Nov 16 2009 Rex Dieter <rdieter@fedoraproject.org> - 1.0.0-2 
- -libs: Requires: sip-api(%%_sip_api_major) >= %%_sip_api (#538124)
- Requires: %%{name}-libs ...

* Thu Oct 29 2009 Sebastian Dziallas <sebastian@when.com> 1.0.0-1
- update to new upstream release

* Tue Oct 20 2009 Rex Dieter <rdieter@fedoraproject.org> 0.9.8-3 
- rebuild (eigen2)

* Sat Sep 26 2009 Sebastian Dziallas <sebastian@when.com> 0.9.8-2
- fix typo in file list

* Sat Sep 26 2009 Sebastian Dziallas <sebastian@when.com> 0.9.8-1
- update to new upstream release
- enable python and glsl support again

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Jun 06 2009 Sebastian Dziallas <sebastian@when.com> 0.9.6-1
- new upstream release to fix issue with qt 4.5.0 and earlier

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-3
- remove remaining python parts
- fix files section finally

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-2
- disable python and glsl for now
- fix files section

* Wed Jun 03 2009 Sebastian Dziallas <sebastian@when.com> 0.9.5-1
- update to new release

* Tue May 12 2009 Sebastian Dziallas <sebastian@when.com> 0.9.4-1
- update to new release

* Fri Apr 10 2009 Sebastian Dziallas <sebastian@when.com> 0.9.3-1
- update to new release

* Sat Mar 21 2009 Sebastian Dziallas <sebastian@when.com> 0.9.2-2
- get desktop file properly installed

* Sat Mar 14 2009 Sebastian Dziallas <sebastian@when.com> 0.9.2-1
- update to new release

* Wed Feb 25 2009 Sebastian Dziallas <sebastian@when.com> 0.9.1-1
- update to new release

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 22 2009 Sebastian Dziallas <sebastian@when.com> 0.9.0-1
- update to new release

* Sun Sep 14 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-6
- add handbook to docs

* Sun Sep 14 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-5
- add build requirements and fix group names

* Wed Aug 13 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-4
- fix typos

* Sat Aug  9 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-3
- reorganize spec file

* Sat Aug  9 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-2
- rename shared library package and structure spec file

* Sun Aug  3 2008 Sebastian Dziallas <sebastian@when.com> 0.8.1-1
- initial pacakging release based on PackMan release
